@@ -1,7 +1,7 @@
 package Data::Section::Seekable;
 
 our $DATE = '2015-06-12'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 1;
 # ABSTRACT: Read and write parts from data section
@@ -18,7 +18,7 @@ Data::Section::Seekable - Read and write parts from data section
 
 =head1 VERSION
 
-This document describes version 0.04 of Data::Section::Seekable (from Perl distribution Data-Section-Seekable), released on 2015-06-12.
+This document describes version 0.05 of Data::Section::Seekable (from Perl distribution Data-Section-Seekable), released on 2015-06-12.
 
 =head1 DESCRIPTION
 
@@ -54,7 +54,7 @@ Example:
 
  Data::Section::Seekable v1
  part1,0,14
- part2,14,17
+ part2,14,17,very,important
 
  This is part1
  This is part
