@@ -1,7 +1,7 @@
 package Data::Section::Seekable::Writer;
 
 our $DATE = '2015-06-12'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -83,7 +83,7 @@ Data::Section::Seekable::Writer - Generate data section with multiple parts
 
 =head1 VERSION
 
-This document describes version 0.04 of Data::Section::Seekable::Writer (from Perl distribution Data-Section-Seekable), released on 2015-06-12.
+This document describes version 0.05 of Data::Section::Seekable::Writer (from Perl distribution Data-Section-Seekable), released on 2015-06-12.
 
 =head1 SYNOPSIS
 
@@ -94,7 +94,7 @@ In your script:
  my $writer = Data::Section::Seekable::Writer->new;
 
  $writer->add_part(part1 => "This is part1\n");
- $writer->add_part(part2 => This is part\ntwo\n");
+ $writer->add_part(part2 => This is part\ntwo\n", "very,important");
  print "__DATA__\n", $writer;
 
 will print:
@@ -102,7 +102,7 @@ will print:
  __DATA__
  Data::Section::Seekable v1
  part1,0,14
- part2,14,17
+ part2,14,17,very,important
 
  This is part1
  This is part
